@@ -1,12 +1,11 @@
 package com.thoughtworks.qdox.model.expression;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertSame;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-import org.junit.Test;
-
 public class PostIncrementTest
 {
     @Test
@@ -15,7 +14,7 @@ public class PostIncrementTest
         AnnotationValue value = mock( AnnotationValue.class );
         when( value.getParameterValue() ).thenReturn( "index" );
         PostIncrement expr = new PostIncrement( value );
-        assertEquals( "index++", expr.getParameterValue() );
+        Assertions.assertEquals("index++", expr.getParameterValue());
     }
 
     @Test
@@ -24,7 +23,7 @@ public class PostIncrementTest
         AnnotationValue value = mock( AnnotationValue.class );
         when( value.getParameterValue() ).thenReturn( "index" );
         PostIncrement expr = new PostIncrement( value );
-        assertEquals( value.toString() + "++", expr.toString() );
+        Assertions.assertEquals(value.toString() + "++", expr.toString());
     }
     
     @Test
@@ -34,6 +33,6 @@ public class PostIncrementTest
         PostIncrement expr = new PostIncrement( null );
         Object visitResult = new Object();
         when( visitor.visit( expr ) ).thenReturn( visitResult );
-        assertSame( expr.accept( visitor ), visitResult );
+        Assertions.assertSame(expr.accept( visitor ), visitResult);
     }
 }
